import { defHttp } from '/src/utils/http/axios';
import { useMessage } from '/src/hooks/web/useMessage';

const { createConfirm } = useMessage();

enum Api {
  list = '/adweb/adwebSite/list',
  save = '/adweb/adwebSite/add',
  edit = '/adweb/adwebSite/edit',
  deleteOne = '/adweb/adwebSite/delete',
  deleteBatch = '/adweb/adwebSite/deleteBatch',
  importExcel = '/adweb/adwebSite/importExcel',
  exportXls = '/adweb/adwebSite/exportXls',
  gtmListUrl = 'gtm/add/list',
  getGoogleAdsAccount = '/marketing/googleads/account/get',
  bindGoogleAdsAccount = '/marketing/googleads/account/add', // 添加绑定接口地址
}

/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls;

/**
 * 导入api
 */
export const getImportUrl = Api.importExcel;

export const gtmListUrl = Api.gtmListUrl;

/**
 * 列表接口
 * @param params
 */
export const list = (params) => defHttp.get({ url: Api.list, params });

/**
 * 删除单个
 * @param params
 * @param handleSuccess
 */
export const deleteOne = (params, handleSuccess) => {
  return defHttp.delete({ url: Api.deleteOne, params }, { joinParamsToUrl: true }).then(() => {
    handleSuccess();
  });
};

/**
 * 批量删除
 * @param params
 * @param handleSuccess
 */
export const batchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认删除',
    content: '是否删除选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({ url: Api.deleteBatch, data: params }, { joinParamsToUrl: true }).then(() => {
        handleSuccess();
      });
    },
  });
};

/**
 * 保存或者更新
 * @param params
 * @param isUpdate
 */
export const saveOrUpdate = (params, isUpdate) => {
  const url = isUpdate ? Api.edit : Api.save;
  return defHttp.post({ url: url, params }, { isTransformResponse: false });
};

/**
 * 获取Google Ads账号信息
 * @param params
 */
export const getGoogleAdsAccount = (params) => defHttp.get({ url: Api.getGoogleAdsAccount, params });

/**
 * 绑定Google Ads账号
 * @param params
 */
export const bindGoogleAdsAccount = (params) => defHttp.post({ url: Api.bindGoogleAdsAccount, params }, { joinParamsToUrl: true });
